@@ -1,12 +1,24 @@
-package JSYNC;
+##
+# name:      JSYNC
+# abstract:  JSON YAML Notation Coding
+# author:    Ingy döt Net <ingy@ingy.net>
+# license:   perl
+# copyright: 2010, 2011
+# see:
+# - http://www.jsync.org/
+# - JSON
+# - YAML
+# - irc.freenode.net#jsync
+
 use 5.008003;
 use strict;
 use warnings;
 
-use JSON;
-# use XXX; # -with => 'Data::Dumper';
+use JSON 2.53;
 
-our $VERSION = '0.12';
+package JSYNC;
+
+our $VERSION = '0.13';
 
 my $next_anchor;
 my $seen;
@@ -192,10 +204,6 @@ sub _unescape {
 
 1;
 
-=head1 NAME
-
-JSYNC - JSON YAML Notation Coding
-
 =head1 STATUS
 
 This is a very early release of JSYNC, and should not be used at all
@@ -221,30 +229,3 @@ Supported so far:
 =head1 DESCRIPTION
 
 JSYNC is an extension of JSON that can serialize any data objects.
-
-See http://www.jsync.org/
-
-=head1 RESOURCES
-
-Web: L<http://www.jsync.org/>
-
-CPAN: L<http://search.cpan.org/dist/JSYNC/>
-
-GitHub: L<http://github.com/ingydotnet/jsync-pm>
-
-IRC: #jsync on irc.freenode.net
-
-=head1 AUTHOR
-
-Ingy döt Net <ingy@cpan.org>
-
-=head1 COPYRIGHT
-
-Copyright (c) 2010. Ingy döt Net.
-
-This program is free software; you can redistribute it and/or modify it
-under the same terms as Perl itself.
-
-See L<http://www.perl.com/perl/misc/Artistic.html>
-
-=cut
